"use client";

import * as React from "react";
import Link, { LinkProps } from "next/link";
import { useRouter } from "next/navigation";

import { cn } from "@/lib/utils";
import { Icons } from "@/components/icons";
import { Sheet, SheetContent, SheetTrigger } from "@/components/ui/sheet";
import { appNavItems, navItems } from "@/constants/data";
import { Button } from "./ui/button";
import { ScrollArea } from "./ui/scroll-area";
import { NavItem } from "@/types";
import { AlignRight } from "lucide-react";
import Image from "next/image";
import ThemeToggle from "./layout/ThemeToggle/theme-toggle";

const mobileNavMenu: NavItem[] = [
  {
    title: "Courses",
    href: "#",
    icon: "dashboard",
    label: "Courses",
  },
  {
    title: "Career Paths",
    href: "#",
    icon: "shieldQuestion",
    label: "Career Paths",
  },
  {
    title: "Community",
    href: "#",
    icon: "shieldQuestion",
    label: "Community",
  },

  {
    title: "Pricing",
    href: "/pricing",
    icon: "profile",
    label: "Pricing",
  },
];

export function MobileNav() {
  const [open, setOpen] = React.useState(false);

  return (
    <Sheet open={open} onOpenChange={setOpen}>
      <SheetTrigger asChild>
        <Button
          variant="ghost"
          className="mr-2 px-0 text-base hover:bg-transparent focus-visible:bg-transparent focus-visible:ring-0 focus-visible:ring-offset-0 md:hidden"
        >
          <AlignRight />
          <span className="sr-only">Toggle Menu</span>
        </Button>
      </SheetTrigger>
      <SheetContent side="right" className="pr-0">
        <MobileLink
          href="/"
          className="flex items-center"
          onOpenChange={setOpen}
        >
          <Link href="/" className="inline-block w-fit">
            <Image
              src="/Skilld AI Logos/Skilld Logo-colour on black.png"
              alt="Skilld Logo"
              width={100}
              height={30}
              className="hidden dark:block h-[25px] w-[80px] md:w-[100px] md:h-[30px] object-contain"
            />
            <Image
              src="/Skilld AI Logos/Skilld Logo-colour.png"
              alt="Skilld Logo"
              width={100}
              height={30}
              className="dark:hidden h-[25px] w-[80px] md:w-[100px] md:h-[30px] object-contain"
            />
          </Link>
        </MobileLink>
        <ScrollArea className="my-4 h-[calc(100vh-8rem)] pb-10 pl-6">
          <div className="flex flex-col space-y-3">
            {appNavItems.mainNav.map(
              (item) =>
                item.href && (
                  <MobileLink
                    key={item.href}
                    href={item.href}
                    onOpenChange={setOpen}
                    className="text-muted-foreground"
                  >
                    {item.title}
                  </MobileLink>
                ),
            )}
          </div>
          <div className="flex flex-col space-y-2">
            {appNavItems.sidebarNav.map((item, index) => (
              <div key={index} className="flex flex-col space-y-3 pt-6">
                <h4 className="font-medium">{item.title}</h4>
                {item?.items?.length &&
                  item.items.map((item) => (
                    <React.Fragment key={item.href}>
                      {!item.disabled &&
                        (item.href ? (
                          <MobileLink
                            href={item.href}
                            onOpenChange={setOpen}
                            className="text-muted-foreground"
                          >
                            {item.title}
                            {item.label && (
                              <span className="ml-2 rounded-md bg-[#adfa1d] px-1.5 py-0.5 text-xs leading-none text-[#000000] no-underline group-hover:no-underline">
                                {item.label}
                              </span>
                            )}
                          </MobileLink>
                        ) : (
                          item.title
                        ))}
                    </React.Fragment>
                  ))}
              </div>
            ))}
          </div>
          <div className="mt-6">
            <ThemeToggle onOpenChange={setOpen} />
          </div>
        </ScrollArea>
      </SheetContent>
    </Sheet>
  );
}

interface MobileLinkProps extends LinkProps {
  onOpenChange?: (open: boolean) => void;
  children: React.ReactNode;
  className?: string;
}

function MobileLink({
  href,
  onOpenChange,
  className,
  children,
  ...props
}: MobileLinkProps) {
  const router = useRouter();
  return (
    <Link
      href={href}
      onClick={() => {
        router.push(href.toString());
        onOpenChange?.(false);
      }}
      className={cn(className)}
      {...props}
    >
      {children}
    </Link>
  );
}
