import { language } from "gray-matter";

const md =
  "# Beginner-Friendly React Tutorial: A Basic React Component\n\nWelcome to this beginner-friendly tutorial to get you started with React. React is a powerful JavaScript library for building user interfaces, most commonly single-page applications.\n\n## Setting Up a New React Project\n\nYou will need Node.js and npm (Node Package Manager) installed on your computer. To create a new React project, you can use the Create React App CLI tool. In your terminal, type:\n\n```bash\nnpx create-react-app my-first-react-app\n```\n\nThis will create a new directory called `my-first-react-app` with all the starter files you need.\n\n## Creating a Simple React Component\n\nEach React component is like a building block for your application. Components can be either class-based or functional. With the introduction of React Hooks, functional components are now powerful and can manage state and side effects.\n\nLet's create a simple functional component that displays a greeting message. In your `src` folder, create a new file named `Greeting.js` and add the following code:\n\n```jsx\nimport React from 'react';\n\nfunction Greeting() {\n  return (\n    <div>\n      <h1>Hello, React!</h1>\n    </div>\n  );\n}\n\nexport default Greeting;\n```\n\n## Using the Greeting Component in App.js\n\nNow let's use the `Greeting` component we just made in our main `App.js` file. Replace the code in `App.js` with the following:\n\n```jsx\nimport React from 'react';\nimport Greeting from './Greeting';\n\nfunction App() {\n  return (\n    <div className='App'>\n      <Greeting />\n    </div>\n  );\n}\n\nexport default App;\n```\n\nNow, if you run `npm start` in your project directory, you should see the greeting \"Hello, React!\" on your browser. This is your first React component in action!\n\n## Conclusion\n\nThis is just the beginning of your journey with React! There are many more concepts to explore such as props, state, lifecycles, hooks, and more. Keep experimenting, building, and learning! React documentation and the community are great resources to help you along your path.\n\nHappy coding!";

export const tutorialData = [
  {
    id: 1,
    language: "react",
    tutorial: [
      {
        id: 1,
        content:
          "Welcome to the React documentation! This page will give you an introduction to the 80% of React concepts that you will use on a daily basis.\r\n" +
          "\r\n" +
          "- How to create and nest components\r\n" +
          "- How to add markup and styles\r\n" +
          "- How to display data\r\n" +
          "- How to render conditions and lists\r\n" +
          "- How to respond to events and update the screen\r\n" +
          "- How to share data between components\r\n",
        code: `
        function Welcome() {
          return (
            <button>
              Welcome
            </button>
          );
        }
    `,
      },
      {
        id: 2,
        content:
          "## Creating and nesting components\r\n" +
          "\r\n" +
          "React apps are made out of _components_. A component is a piece of the UI (user interface) that has its own logic and appearance. A component can be as small as a button, or as large as an entire page.\r\n" +
          "\r\n" +
          "React components are JavaScript functions that return markup:\r\n" +
          "\r\n" +
          "```js\r\n" +
          "function MyButton() {\r\n" +
          "  return <button>I'm a button</button>;\r\n" +
          "}\r\n" +
          "```\r\n" +
          "\r\n" +
          "Now that you've declared `MyButton`, you can nest it into another component:\r\n" +
          "\r\n" +
          "```js {5}\r\n" +
          "export default function MyApp() {\r\n" +
          "  return (\r\n" +
          "    <div>\r\n" +
          "      <h1>Welcome to my app</h1>\r\n" +
          "      <MyButton />\r\n" +
          "    </div>\r\n" +
          "  );\r\n" +
          "}\r\n" +
          "```\r\n" +
          "\r\n" +
          "Notice that `<MyButton />` starts with a capital letter. That's how you know it's a React component. React component names must always start with a capital letter, while HTML tags must be lowercase.\r\n" +
          "\r\n" +
          "**_Have a look at the result(in the right side code editor)_**\r\n" +
          "\r\n" +
          "The `export default` keywords specify the main component in the file. If you're not familiar with some piece of JavaScript syntax, [MDN](https://developer.mozilla.org/en-US/docs/web/javascript/reference/statements/export) and [javascript.info](https://javascript.info/import-export) have great references.\r\n",
        code: `
        import * as React from 'react';  //don't change this line
      
        function MyApp() {
          return (
            <div>
              <h1>Welcome to my app</h1>
              <MyButton />
            </div>
          );
        }
      
        function MyButton() {
          return (
            <button>
              I'm a button
            </button>
          );
        }
        `,
      },
      {
        id: 3,
        content:
          "## Writing markup with JSX\r\n" +
          "\r\n" +
          "The markup syntax you've seen above is called *JSX*. It is optional, but most React projects use JSX for its convenience. All of the [tools we recommend for local development](/learn/installation) support JSX out of the box.\r\n" +
          "\r\n" +
          "JSX is stricter than HTML. You have to close tags like `<br />`. Your component also can't return multiple JSX tags. You have to wrap them into a shared parent, like a `<div>...</div>` or an empty `<>...</>` wrapper:\r\n" +
          "\r\n" +
          "```js\r\n" +
          "function AboutPage() {\r\n" +
          "  return (\r\n" +
          "    <>\r\n" +
          "      <h1>About</h1>\r\n" +
          "      <p>Hello there.<br />How do you do?</p>\r\n" +
          "    </>\r\n" +
          "  );\r\n" +
          "}\r\n" +
          "```\r\n" +
          "\r\n" +
          "If you have a lot of HTML to port to JSX, you can use an [online converter.](https://transform.tools/html-to-jsx)",
        code: `
        function AboutPage() {
          return (
            <>
              <h1>About</h1>
              <p>Hello there.<br />How do you do?</p>
            </>
          );
        }
        `,
      },
    ],
  },
  {
    id: 2,
    language: "javascript",
    tutorial: [
      {
        id: 1,
        content: "# Welcome to `javascript` tutorial",
        code: `\nfunction greet(name) {\n\tconsole.log("Hello, " + name + "!");\n}\n\ngreet("Mehedi");\n`,
      },
    ],
  },
  {
    id: 3,
    language: "typescript",
    tutorial: [
      {
        id: 1,
        content: "# Welcome to `typescript` tutorial",
        code: `\ntype Params = {\n\tname: string;\n}\n\nfunction greet(data: Params) {\n\tconsole.log("Hello, " + data.name + "!");\n}\n\ngreet({ name: "Mehedi" });\n`,
      },
    ],
  },
  {
    id: 4,
    language: "python",
    tutorial: [
      {
        id: 1,
        content: "# Welcome to `python` tutorial",
        code: `\ndef greet(name):\n\tprint("Hello, " + name + "!")\n\ngreet("Mehedi")\n`,
      },
    ],
  },
  {
    id: 5,
    language: "java",
    tutorial: [
      {
        id: 1,
        content: "# Welcome to `java` tutorial",
        code: `\npublic class HelloWorld {\n\tpublic static void main(String[] args) {\n\t\tSystem.out.println("Hello World");\n\t}\n}\n`,
      },
    ],
  },
  {
    id: 6,
    language: "csharp",
    tutorial: [
      {
        id: 1,
        content: "# Welcome to `csharp` tutorial",
        code: 'using System;\n\nnamespace HelloWorld\n{\n\tclass Hello { \n\t\tstatic void Main(string[] args) {\n\t\t\tConsole.WriteLine("Hello World in C#");\n\t\t}\n\t}\n}\n',
      },
    ],
  },
  {
    id: 7,
    language: "php",
    tutorial: [
      {
        id: 1,
        content: "# Welcome to `php` tutorial",
        code: "<?php\n\n$name = 'Mehedi';\necho $name;\n",
      },
    ],
  },
];
